@@ -7,7 +7,6 @@
 */
 
 #include "signatureconfigurator.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "identity.h"
 #include "signaturerichtexteditor_p.h"
@@ -43,6 +42,7 @@ using namespace Qt::Literals::StringLiterals;
 
 #include <TextCustomEditor/RichTextEditorWidget>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace KIdentityManagementWidgets;
 
 namespace KIdentityManagementWidgets
@@ -91,9 +91,9 @@ QString SignatureConfiguratorPrivate::asCleanedHTML() const
     const QString html = textDocument.toHtml();
 
     // Now remove each line from the text, the result is clean html.
-    const QStringList lst = html.split(QLatin1Char('\n'));
+    const QStringList lst = html.split(u'\n');
     for (const QString &line : lst) {
-        text.remove(line + QLatin1Char('\n'));
+        text.remove(line + u'\n');
     }
     return text;
 }
@@ -145,7 +145,7 @@ void SignatureConfiguratorPrivate::init()
     auto page = new QWidget(widgetStack);
     widgetStack->insertWidget(pageno, page);
     auto page_vlay = new QVBoxLayout(page);
-    page_vlay->setContentsMargins(0, 0, 0, 0);
+    page_vlay->setContentsMargins({});
 
 #ifndef QT_NO_TOOLBAR
     mEditToolBar = new KToolBar(q);
@@ -167,37 +167,37 @@ void SignatureConfiguratorPrivate::init()
     auto actionCollection = new KActionCollection(q);
     mTextEdit->createActions(actionCollection);
 #ifndef QT_NO_TOOLBAR
-    mEditToolBar->addAction(actionCollection->action(QStringLiteral("format_text_bold")));
-    mEditToolBar->addAction(actionCollection->action(QStringLiteral("format_text_italic")));
-    mEditToolBar->addAction(actionCollection->action(QStringLiteral("format_text_underline")));
-    mEditToolBar->addAction(actionCollection->action(QStringLiteral("format_text_strikeout")));
-    mEditToolBar->addAction(actionCollection->action(QStringLiteral("format_text_foreground_color")));
-    mEditToolBar->addAction(actionCollection->action(QStringLiteral("format_text_background_color")));
-    mEditToolBar->addAction(actionCollection->action(QStringLiteral("format_font_family")));
-    mEditToolBar->addAction(actionCollection->action(QStringLiteral("format_font_size")));
-    mEditToolBar->addAction(actionCollection->action(QStringLiteral("format_reset")));
+    mEditToolBar->addAction(actionCollection->action(u"format_text_bold"_s));
+    mEditToolBar->addAction(actionCollection->action(u"format_text_italic"_s));
+    mEditToolBar->addAction(actionCollection->action(u"format_text_underline"_s));
+    mEditToolBar->addAction(actionCollection->action(u"format_text_strikeout"_s));
+    mEditToolBar->addAction(actionCollection->action(u"format_text_foreground_color"_s));
+    mEditToolBar->addAction(actionCollection->action(u"format_text_background_color"_s));
+    mEditToolBar->addAction(actionCollection->action(u"format_font_family"_s));
+    mEditToolBar->addAction(actionCollection->action(u"format_font_size"_s));
+    mEditToolBar->addAction(actionCollection->action(u"format_reset"_s));
 
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("format_list_style")));
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("format_list_indent_more")));
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("format_list_indent_less")));
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("format_list_indent_less")));
+    mFormatToolBar->addAction(actionCollection->action(u"format_list_style"_s));
+    mFormatToolBar->addAction(actionCollection->action(u"format_list_indent_more"_s));
+    mFormatToolBar->addAction(actionCollection->action(u"format_list_indent_less"_s));
+    mFormatToolBar->addAction(actionCollection->action(u"format_list_indent_less"_s));
     mFormatToolBar->addSeparator();
 
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("format_align_left")));
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("format_align_center")));
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("format_align_right")));
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("format_align_justify")));
+    mFormatToolBar->addAction(actionCollection->action(u"format_align_left"_s));
+    mFormatToolBar->addAction(actionCollection->action(u"format_align_center"_s));
+    mFormatToolBar->addAction(actionCollection->action(u"format_align_right"_s));
+    mFormatToolBar->addAction(actionCollection->action(u"format_align_justify"_s));
     mFormatToolBar->addSeparator();
 
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("insert_horizontal_rule")));
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("manage_link")));
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("format_painter")));
+    mFormatToolBar->addAction(actionCollection->action(u"insert_horizontal_rule"_s));
+    mFormatToolBar->addAction(actionCollection->action(u"manage_link"_s));
+    mFormatToolBar->addAction(actionCollection->action(u"format_painter"_s));
 
     mFormatToolBar->addSeparator();
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("add_image")));
+    mFormatToolBar->addAction(actionCollection->action(u"add_image"_s));
     mFormatToolBar->addSeparator();
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("insert_html")));
-    mFormatToolBar->addAction(actionCollection->action(QStringLiteral("insert_table")));
+    mFormatToolBar->addAction(actionCollection->action(u"insert_html"_s));
+    mFormatToolBar->addAction(actionCollection->action(u"insert_table"_s));
 #endif
 
     hlay = new QHBoxLayout(); // inherits spacing
@@ -214,7 +214,7 @@ void SignatureConfiguratorPrivate::init()
     page = new QWidget(widgetStack);
     widgetStack->insertWidget(pageno, page); // force sequential numbers (play safe)
     page_vlay = new QVBoxLayout(page);
-    page_vlay->setContentsMargins(0, 0, 0, 0);
+    page_vlay->setContentsMargins({});
     hlay = new QHBoxLayout(); // inherits spacing
     page_vlay->addLayout(hlay);
     mFileRequester = new KUrlRequester(page);
@@ -243,7 +243,7 @@ void SignatureConfiguratorPrivate::init()
     page = new QWidget(widgetStack);
     widgetStack->insertWidget(pageno, page);
     page_vlay = new QVBoxLayout(page);
-    page_vlay->setContentsMargins(0, 0, 0, 0);
+    page_vlay->setContentsMargins({});
     hlay = new QHBoxLayout(); // inherits spacing
     page_vlay->addLayout(hlay);
     mCommandEdit = new KLineEdit(page);
@@ -330,7 +330,7 @@ QString SignatureConfigurator::filePath() const
     // Force the filename to be relative to ~ instead of $PWD depending
     // on the rest of the code (KRun::run in Edit and KFileItem on save)
     if (!file.isEmpty() && QFileInfo(file).isRelative()) {
-        file = QDir::home().absolutePath() + QLatin1Char('/') + file;
+        file = QDir::home().absolutePath() + u'/' + file;
     }
     return file;
 }
@@ -428,7 +428,7 @@ void SignatureConfigurator::slotEdit()
     // slotEnableEditButton should prevent this assert from being hit:
     assert(!url.isEmpty());
 
-    auto job = new KIO::OpenUrlJob(QUrl::fromLocalFile(url), QStringLiteral("text/plain"));
+    auto job = new KIO::OpenUrlJob(QUrl::fromLocalFile(url), u"text/plain"_s);
     job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
     job->start();
 }
@@ -466,8 +466,7 @@ void SignatureConfigurator::setImageLocation(const QString &path)
 
 void SignatureConfigurator::setImageLocation(const KIdentityManagementCore::Identity &identity)
 {
-    const QString dir =
-        QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/emailidentities/%1/").arg(QString::number(identity.uoid()));
+    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + u"/emailidentities/%1/"_s.arg(QString::number(identity.uoid()));
     QDir().mkpath(dir);
     setImageLocation(dir);
 }
